Index: trunk/CHANGELOG
===================================================================
--- trunk/CHANGELOG	(revision 724)
+++ trunk/CHANGELOG	(revision 725)
@@ -12,6 +12,7 @@
 
 ------------------------------------- 2.7.0 -------------------------------------
 23-Feb-2008 Christian Sommer
+!	suppressed warnings in initialize.php if constant already defined; modified upgrade script to make FCK the new default editor
 #	fixed bug in upgrade script (WBMailer setting)
 22-Feb-2008 Christian Sommer
 #	some layout changes on the upgrade-script, fixed error in precheck
@@ -45,7 +46,7 @@
 #	fixed an highlighting-issue: highlighting a page with more than one sections mangled umlauts in the second to last section.
 10-Feb-2008 Matthias Gallas
 #	fixed some errors in standard german language file
-+	added new colloquially german language file (thanks to Michael Tenschert)
++	added new colloquially german language file
 10-Feb-2008 Thomas Hornik
 #	CAPTCHA: Wrong text for calc_ttf-captcha. 
 10-Feb-2008 Christian Sommer
Index: trunk/wb/framework/initialize.php
===================================================================
--- trunk/wb/framework/initialize.php	(revision 724)
+++ trunk/wb/framework/initialize.php	(revision 725)
@@ -44,7 +44,7 @@
 			$setting_value=false;
 		if ($setting_value=='true')
 			$setting_value=true;
-		define($setting_name,$setting_value);
+		@define($setting_name,$setting_value);
 	}
 	$string_file_mode = STRING_FILE_MODE;
 	define('OCTAL_FILE_MODE',(int) octdec($string_file_mode));

Index: trunk/wb/upgrade-script.php
===================================================================
--- trunk/wb/upgrade-script.php	(revision 724)
+++ trunk/wb/upgrade-script.php	(revision 725)
@@ -766,10 +766,14 @@
 }
 
 /**********************************************************
  *  - Alter the WYSIWYG editor content from text to longtext
  */
-echo "<br /><u>Alter WYSIWYG editor content field from text to longtext</u><br />Status: ";
+echo "<br /><u>Alter WYSIWYG editor settings</u><br />Alter field content from text to longtext: ";
 echo ($database->query("ALTER TABLE ".TABLE_PREFIX."mod_wysiwyg MODIFY content LONGTEXT NOT NULL")) ?" $OK<br />" : " $FAIL<br />";
+if(file_exists(WB_PATH .'/modules/fckeditor/include.php')) {
+	echo "Make FCKEditor the new default editor: ";
+	echo ($database->query("UPDATE ".TABLE_PREFIX."settings SET value='fckeditor' WHERE name='wysiwyg_editor'")) ?" $OK<br />" : " $FAIL<br />";
+}
 
 /**********************************************************
  *  - Add Admintools to Administrator group
@@ -766,10 +766,14 @@
 
 /**********************************************************
- *  - Alter the WYSIWYG editor content from text to longtext
+ *  - Alter the WYSIWYG editor (longtext, default FCK)
  */